==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/CreateUpdateIamRolePermissionRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PermissionConditions;
import org.openapitools.jackson.nullable.JsonNullable;
import com.fasterxml.jackson.annotation.JsonIgnore;
import org.openapitools.jackson.nullable.JsonNullable;
import java.util.NoSuchElementException;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CreateUpdateIamRolePermissionRequest
 */
@JsonPropertyOrder({ CreateUpdateIamRolePermissionRequest.JSON_PROPERTY_CONDITIONS })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CreateUpdateIamRolePermissionRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONDITIONS = "conditions";
    private JsonNullable<PermissionConditions> conditions = JsonNullable.<PermissionConditions> undefined();

    public CreateUpdateIamRolePermissionRequest() {
    }

    public CreateUpdateIamRolePermissionRequest conditions(PermissionConditions conditions) {
        this.conditions = JsonNullable.<PermissionConditions> of(conditions);

        return this;
    }

    /**
     * Get conditions
     *
     * @return conditions
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonIgnore

    public PermissionConditions getConditions() {
        return conditions.orElse(null);
    }

    @JsonProperty(JSON_PROPERTY_CONDITIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public JsonNullable<PermissionConditions> getConditions_JsonNullable() {
        return conditions;
    }

    @JsonProperty(JSON_PROPERTY_CONDITIONS)
    public void setConditions_JsonNullable(JsonNullable<PermissionConditions> conditions) {
        this.conditions = conditions;
    }

    public void setConditions(PermissionConditions conditions) {
        this.conditions = JsonNullable.<PermissionConditions> of(conditions);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CreateUpdateIamRolePermissionRequest createUpdateIamRolePermissionRequest = (CreateUpdateIamRolePermissionRequest) o;
        return equalsNullable(this.conditions, createUpdateIamRolePermissionRequest.conditions);
        // ;
    }

    private static <T> boolean equalsNullable(JsonNullable<T> a, JsonNullable<T> b) {
        return a == b
                || (a != null && b != null && a.isPresent() && b.isPresent() && Objects.deepEquals(a.get(), b.get()));
    }

    @Override
    public int hashCode() {
        return Objects.hash(hashCodeNullable(conditions));
    }

    private static <T> int hashCodeNullable(JsonNullable<T> a) {
        if (a == null) {
            return 1;
        }
        return a.isPresent() ? Arrays.deepHashCode(new Object[] { a.get() }) : 31;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CreateUpdateIamRolePermissionRequest {\n");
        sb.append("    conditions: ").append(toIndentedString(conditions)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/CreateUpdateIamRolePermissionRequest.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PermissionConditions;
import org.openapitools.jackson.nullable.JsonNullable;
import com.fasterxml.jackson.annotation.JsonIgnore;
import org.openapitools.jackson.nullable.JsonNullable;
import java.util.NoSuchElementException;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * CreateUpdateIamRolePermissionRequest
 */
@JsonPropertyOrder({ CreateUpdateIamRolePermissionRequest.JSON_PROPERTY_CONDITIONS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class CreateUpdateIamRolePermissionRequest implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CONDITIONS = "conditions";
    private JsonNullable<PermissionConditions> conditions = JsonNullable.<PermissionConditions> undefined();

    public CreateUpdateIamRolePermissionRequest() {
    }

    public CreateUpdateIamRolePermissionRequest conditions(PermissionConditions conditions) {
        this.conditions = JsonNullable.<PermissionConditions> of(conditions);

        return this;
    }

    /**
     * Get conditions
     *
     * @return conditions
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonIgnore

    public PermissionConditions getConditions() {
        return conditions.orElse(null);
    }

    @JsonProperty(JSON_PROPERTY_CONDITIONS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public JsonNullable<PermissionConditions> getConditions_JsonNullable() {
        return conditions;
    }

    @JsonProperty(JSON_PROPERTY_CONDITIONS)
    public void setConditions_JsonNullable(JsonNullable<PermissionConditions> conditions) {
        this.conditions = conditions;
    }

    public void setConditions(PermissionConditions conditions) {
        this.conditions = JsonNullable.<PermissionConditions> of(conditions);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CreateUpdateIamRolePermissionRequest createUpdateIamRolePermissionRequest = (CreateUpdateIamRolePermissionRequest) o;
        return equalsNullable(this.conditions, createUpdateIamRolePermissionRequest.conditions);
        // ;
    }

    private static <T> boolean equalsNullable(JsonNullable<T> a, JsonNullable<T> b) {
        return a == b
                || (a != null && b != null && a.isPresent() && b.isPresent() && Objects.deepEquals(a.get(), b.get()));
    }

    @Override
    public int hashCode() {
        return Objects.hash(hashCodeNullable(conditions));
    }

    private static <T> int hashCodeNullable(JsonNullable<T> a) {
        if (a == null) {
            return 1;
        }
        return a.isPresent() ? Arrays.deepHashCode(new Object[] { a.get() }) : 31;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CreateUpdateIamRolePermissionRequest {\n");
        sb.append("    conditions: ").append(toIndentedString(conditions)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
